@@ -1,11 +1,8 @@
-
 """
-	Result types for Impossible FX Project API
-	API Version: 2016-06-02
-	Generated: timestamp
+Result types for Impossible FX Project API
 
-	Please send suggestions and bug reports to:
-	python-sdk@impossiblesoftware.com
+Please send suggestions and bug reports to:
+python-sdk@impossiblesoftware.com
 """
 
 import fxservice
